@@ -102,7 +102,7 @@ fn display_single_column(
                 .style(style)
                 .to_string(),
         );
-        formatted_line.push_str(&replace_tabs(line, display_options.tab_width));
+        formatted_line.push_str(line);
         formatted_lines.push(formatted_line);
     }
 
@@ -339,6 +339,17 @@ pub(crate) fn print(
         )
     };
 
+    // Style positions are relative to the source code offsets. Now
+    // that we've applied styling, we can replace tabs.
+    let lhs_colored_lines: Vec<_> = lhs_colored_lines
+        .iter()
+        .map(|l| replace_tabs(l, display_options.tab_width))
+        .collect();
+    let rhs_colored_lines: Vec<_> = rhs_colored_lines
+        .iter()
+        .map(|l| replace_tabs(l, display_options.tab_width))
+        .collect();
+
     if lhs_src.is_empty() {
         for line in display_single_column(
             display_path,
